#delimit ;
*census_spouse_wrace.do ;
capture log close ;
*log using "F:\Schwartz\rs_eam\filecreation\census_spouse_wrace.log",replace ;
log using "census_spouse_wrace.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 2050m ;


****************************************************
*                                                  *
* This file creates an individual-level file       *
* of married couples for each year in the census.  *
*                                                  *
*                                                  *
**************************************************** ;

     #delimit ;



     local varlist1 "year
                     serial
                     gq
                     pernum
                     perwt
                     sploc
                     age
                     sex
                     raceg
                     marst
                     agemarr
                     educrec
                     higraded
                     bpl
                     marrqtr
                     birthqtr
                     nativity" ;

     local varlist2 "year
                     serial
                     gq
                     pernum
                     perwt
                     sploc
                     age
                     sex
                     raceg
                     marst
                     agemarr
                     educrec
                     higraded
                     educ99
                     bpl
                     marrqtr
                     birthqtr
                     nativity" ;

     *use `varlist1' using "F:\Schwartz\rs_eam\raw\census\schwa053.dta", clear ;
      use `varlist1' using "schwa053.dta", clear ;

      tempfile c4070 ;
      save `c4070' ;


     *use `varlist2' using "F:\Schwartz\rs_eam\raw\census\schwa052.dta", clear ;
     use `varlist2' using "schwa052.dta", clear ;

      append using `c4070' ;


     keep if age >= 15  ;


   *Drop 1950 because does not contain spouse info ;

   drop if year == 95 ;

   tab year ;
   tab year if age <= 78;




*drop if in group quarters ;


    tab gq ;

    drop if gq == 3 | gq == 4 ;

    tab gq ;
    tab year ;
    tab year if age <= 78 ;


*Keep married people w/spouse present ;

    tab marst ;

    keep if marst == 1 ;




**Look to see how the census categorized the highest
  grade completed/attended questions in their recoded
  variable ;

tab higraded educrec ;
tab educ99 educrec ;



 *NOTE: I am creating four different educational attainment
        variables here.  The versions are as follows:

        (1) "Standard" version.  This verion follows the
            recommendations outlined by economists.

            Pre change:               Post change:
            HGA but not C             12 no diploma =
            13 = 13                   12


        (2) Pre change:               Post change:
            HGA but not C             12 no diploma =
            13 = 13                   11


        (3) Pre change:               Post change:
            HGA but not C             12 no diploma =
            13 = 12                   12


        (4) Pre change:               Post change:
            HGA but not C             12 no diploma =
            13 = 12                   11


        -crs 4/19/05 ;



**Here's the STANDARD version ;


   **the census is categorizing people who did not complete
     or are attending their first year of college as having
     12 years of schooling. For my time series I want to code
     these people as having "some college." ;


   gen ed = educrec ;
   replace ed = 8 if higraded == 151 | higraded == 152 ;


   tab higraded ed ;
   tab educ99 ed ;




**VERSION 2 ;


   gen edv2 = educrec ;
   replace edv2 = 8 if higraded == 151 | higraded == 152 ;

   **After 1990 the census is also categorizing people who
     completed 12 years of schooling but did not receive
     a high chool diploma or GED as "grade 12." Move these
     people to 11 ;

   replace edv2 = 6 if educ99 == 9 ;


   tab higraded edv2 ;
   tab educ99 edv2   ;




**VERSION 3 ;

   gen edv3 = educrec ;

   tab higraded edv3 ;
   tab educ99 edv3   ;


**VERSION 4 ;


   gen edv4 = educrec ;

   **After 1990 the census is also categorizing people who
     completed 12 years of schooling but did not receive
     a high chool diploma or GED as "grade 12." Move these
     people to 11 ;

   replace edv4 = 6 if educ99 == 9 ;


   tab higraded edv4 ;
   tab educ99 edv4   ;




**Define natives as those born in the U.S. or outlying areas/territories ;

gen native = (bpl >= 1 & bpl <= 120) ;

tab native ;


   **Check ;

     tab bpl native ;



**Define a race variable. Black, white, and other ;

gen race_c = raceg ;
recode race_c 3/9 = 3 ;


   **Check ;

     tab raceg race_c ;




**crs 3/10/04 -- I checked the above code it works. ;



tempfile revc4070 ;
save `revc4070' ;



*MATCH SPOUSES TO EACH OTHER.  This code is in Chapter
 5 of the IPUMS documentation "Family Interrelationships." ;

keep serial sploc age sex race_c marst agemarr educrec year perwt higraded educ99 native ed edv* ;

rename sploc pernum ;


quietly for var age sex race_c marst agemarr  educrec perwt higraded educ99 native ed edv2 edv3 edv4: rename X sX ;

sort year serial pernum ;

tempfile spouse ;
save `spouse' ;

clear ;

set mem 2000m ;

use `revc4070', clear ;

tab year ;
tab year if age <= 78 ;

sort year serial pernum ;

merge year serial pernum using `spouse', unique ;


*Cases that don't have a spouse match ;

   tab marst _merge ;
   tab year _merge if age <= 78;

   keep if _merge == 3 & marst == 1 ;
   drop _merge ;

   tab year ;
   tab year if age <= 78 ;





*Recode year ;

   recode year 00 = 2000 94 = 1940 96 = 1960 97 = 1970 98 = 1980 99 = 1990 ;


*Make husband and wife education. ;

  gen     hed = ed if sex == 1 ;
  replace hed = sed if sex == 2;

  gen     wed = ed if sex == 2  ;
  replace wed = sed if sex == 1 ;

  gen     hedv2 = edv2 if sex == 1 ;
  replace hedv2 = sedv2 if sex == 2;

  gen     wedv2 = edv2 if sex == 2  ;
  replace wedv2 = sedv2 if sex == 1 ;

  gen     hedv3 = edv3 if sex == 1 ;
  replace hedv3 = sedv3 if sex == 2;

  gen     wedv3 = edv3 if sex == 2  ;
  replace wedv3 = sedv3 if sex == 1 ;

  gen     hedv4 = edv4 if sex == 1 ;
  replace hedv4 = sedv4 if sex == 2;

  gen     wedv4 = edv4 if sex == 2  ;
  replace wedv4 = sedv4 if sex == 1 ;

  gen     weduc99 = educ99 if sex == 2 ;
  replace weduc99 = seduc99 if sex == 1 ;

  gen     heduc99 = educ99 if sex == 1 ;
  replace heduc99 = seduc99 if sex == 2 ;

  gen     whigrd = higraded if sex == 2 ;
  replace whigrd = shigraded if sex == 1 ;

  gen     hhigrd = higraded if sex == 1 ;
  replace hhigrd = shigraded if sex == 2 ;



*When does the wife report getting married? Use her report to define
 newlyweds.  "Newlyweds" are those married within 2 years prior to
 survey ;


  gen wagemarr = agemarr if sex == 2  ;


*Wife's age;

  gen wage     = age if sex == 2 ;
  replace wage = sage if sex == 1;

*Husband's age;

  gen hage     = age if sex == 1 ;
  replace hage = sage if sex == 2;



*Wife's race;

  gen wr     = race_c if sex == 2 ;
  replace wr = srace_c if sex == 1;

*Husband's race;

  gen hr     = race_c if sex == 1 ;
  replace hr = srace_c if sex == 2;



*Wife's nativity;

  gen wnv     = native  if sex == 2 ;
  replace wnv = snative if sex == 1;

*Husband's nativity;

  gen hnv     = native  if sex == 1 ;
  replace hnv = snative if sex == 2;


*Wife's PERSON WEIGHT --- All but 1940 and 2000 are self weighting ;

  gen wperwt     = perwt if sex == 2 & (year == 1940 | year == 2000) ;
  replace wperwt = sperwt if sex == 1 & (year == 1940 | year == 2000) ;
  replace wperwt = 1 if (year > 1940 & year < 2000) ;


*Newlywed.  In 1940 define newlyweds by age at marriage but in
 1960 to 1980 quarter of marriage is available. ;

  forvalues i = 1/7 { ;
   local j = `i' - 1 ;
    gen new`i'= ((wage - wagemarr) <  `i' &  (wage - wagemarr) >= `j' & wagemarr ~= .) if year == 1940 ;
  } ;

*1960 through 1980.  You are supposed to tell the gov't about your life
*as of April 1st.(Quarter 2)  ;


  *Birth year
   Birthqtr is available only in 1960 1970 and 1980
   The following code takes everybody's age they give
   as given and calculates their year of birth accordingly ;

   gen byear = (year - wage    ) if birthqtr <= 2 & (year >= 1960 & year <= 1980) ;
   replace byear = (year - wage - 1) if birthqtr >  2 & (year >= 1960 & year <= 1980);


  *Age in quarters at interview (Interview is April 1 always quarter 2)
   Birthqtr is available only in 1960 1970 and 1980 ;

   gen qage = (year - byear)*4 + (2 - birthqtr) if (year >= 1960 & year <= 1980);



  *Divide by 4 to get age in years with fractions in quarters ;

   gen owage = wage ;
   replace wage = qage/4 if (year >= 1960 & year <= 1980) ;


  *Fraction to be added and subtracted to wagemarr based on
  *quarter of marriage and quarter of birth info ;

  *The age at marrige variable is calculated from month
  *and year of marriage. Here, I use the quarter of marriage
  *and birth data to add fractions to the age at marraige
  *variable.  ;

   gen qfract = (4 - abs(birthqtr - marrqtr))/4 ;

  *Add fractions to add if necessary ;
   gen qmage = wagemarr ;
   replace qmage = wagemarr + qfract if qfract ~= 1 & qfract ~= . ;


    preserve ;
     keep if year == 1980 & sex == 2 ;
     list year owage wage wagemarr marrqtr birthqtr byear qfract qmage in 1/50, nolab ;
    restore ;

    gen dur = wage - qmage  if year < 1990 ;

    summarize dur, detail ;
    bysort year: summarize dur, detail ;

    replace new1 = (wage - qmage < 1) & year ~= 1940 ;

  forvalues i = 2/7 { ;
   local j = `i' - 1 ;
    replace new`i'= (wage - qmage < `i' & wage - qmage >= `j') if year ~= 1940 ;
  } ;


    preserve ;
     keep if year == 1980 & sex == 2 & (new1 == 1 | new2 == 1 | new3 == 1 | new5 == 1) ;
     list year wage qmage wagemarr dur new1 new2 new3 new5 in 1/15, nolab ;
    restore ;

    preserve ;
     keep if dur < -5 ;
     list year wage qmage wagemarr dur owage, nolab ;
    restore ;



*Only keep one of the observations. Make it the wife's obs.
 It's a couple level file ;


  tab new1 ;

  keep if sex == 2 ;

  tab new1 ;

  tab year ;
  tab year if age <= 78 ;


*Education categories ;


  gen hedc = hed ;
  gen wedc = wed ;

  recode hedc 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;
  recode wedc 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;

  label var hedc "H's Ed: <10,10-11,12,13-15,16+" ;
  label var wedc "W's Ed: <10,10-11,12,13-15,16+" ;


  lab def edc 1 "1:lt10"
              2 "2:10-11"
              3 "3:12"
              4 "4:13-15"
              5 "5:ge16" ;

  lab val hedc edc ;
  lab val wedc edc ;

  gen hedcv2 = hedv2 ;
  gen wedcv2 = wedv2 ;

  recode hedcv2 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;
  recode wedcv2 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;

  gen hedcv3 = hedv3 ;
  gen wedcv3 = wedv3 ;

  recode hedcv3 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;
  recode wedcv3 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;

  gen hedcv4 = hedv4 ;
  gen wedcv4 = wedv4 ;

  recode hedcv4 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;
  recode wedcv4 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;


*More detailed ed categories ;

  gen hedc_d = hed ;
  gen wedc_d = wed ;

  recode hedc_d 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;
  recode wedc_d 1/4 = 1 5/6 = 2 7 = 3 8 = 4 9 = 5 ;

  replace hedc_d = 6 if hhigrd >= 200 & hhigrd <= 230 ;
  replace wedc_d = 6 if whigrd >= 200 & whigrd <= 230 ;

  replace hedc_d = 6 if heduc99 >= 15 & heduc99 <= 17 ;
  replace wedc_d = 6 if weduc99 >= 15 & weduc99 <= 17 ;

  label var hedc_d "H's Ed: <12,13-15,16,>16" ;
  label var wedc_d "W's Ed: <12,13-15,16,>16" ;

  ***Create the most detailed measure of education
     that is still relatively consistent across
     years.  Use Park (1996:426) 10 category
     scheme. ;

  gen hedc_dd = hed ;
  gen wedc_dd = wed ;

  replace hedc_dd = 10 if hhigrd >= 200 & hhigrd <= 230 ;
  replace wedc_dd = 10 if whigrd >= 200 & whigrd <= 230 ;

  replace hedc_dd = 10 if heduc99 >= 15 & heduc99 <= 17 ;
  replace wedc_dd = 10 if weduc99 >= 15 & weduc99 <= 17 ;

  lab def edc_dd 1 "1:lt1"
                 2 "2:1-4"
                 3 "3:5-8"
                 4 "4:9"
                 5 "5:10"
                 6 "6:11"
                 7 "7:12"
                 8 "8:13-15"
                 9 "9:16"
                10 "10:gt16" ;

  lab val hedc_dd edc_dd ;
  lab val wedc_dd edc_dd ;

  label var hedc_dd "H's Ed: 10 cat" ;
  label var wedc_dd "W's Ed: 10 cat" ;




  lab def r 1 "1:white" 2 "2:black" 3 "3:other" ;
  lab val hr r ;
  lab val wr r ;


*Weight is equal to the wife's person weight;

  rename wperwt WEIGHT ;

tab year if owage >= 16 & owage < 41 ;
tab year if owage >= 18 & owage < 41 ;
tab year if owage <=78 ;
tab year if  wage >= 18 &  wage < 41 ;
tab year ;


quietly compress ;
*save "F:\Schwartz\rs_eam\data\census_spouse_wrace.dta", replace ;
save "census_spouse_wrace.dta", replace ;


