#delimit ;
*couples_o6878.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\filecreation\couples_o6878.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;


#delimit cr


 **Now October 1968-1978


 **SOURCE:  These data are from the UNICON CD for the October Supplement,
 **         1971-2000.



     use "F:\Schwartz\cps_historical\raw\odat68_78\oct68.dta", clear


     foreach num of numlist 69/78 {
      quietly append using "F:\Schwartz\cps_historical\raw\odat68_78\oct`num'.dta"
     }





     *What's in this file?

      describe


    ****Now define married couples***


    destring _year, replace


    replace spneth = "10" if spneth == "A"
    destring spneth, replace


    sort _year hhid lineno



     *Identify married people (spouse present)



       gen m = (marstat == 1 | marstat == 2)  /*1= civilian spouse present
                                                2= AF spouse present*/

       tab _year m, row
       keep if m == 1



  *Keep married couples

      keep if rrp == 1 | rrp == 3





  *Drop if there is more than one married couple in the household


      bysort _year mis state hhnum hhid subhh: egen summ = sum(m)

      tab summ
      gen xsum = (summ ~= 2)

      tab _year xsum, row

      drop xsum


      drop if summ ~= 2





  *Drop if they appear to be same sex.


      bysort _year mis state hhnum hhid subhh: egen sumsex = sum(sex)

      tab sumsex


      keep if sumsex == 3






  #delimit ;

 *Educational attainment.

  NOTE: The variables which indicate educational attainment
        switched in 1992. Pre-1992 there are two varaibles
        that need to be used to construct a highest grade
        of school completed variable: grdhi (hiest grade
        attended) and grdcom (highest grade completed). In
        1992 and after, there is a single variable, grdatn,
        which indicates highest grade completed. Therefore,
        I have to do the coding in two steps. (However,
        1992 has both sets of variables)       -crs 9/6/01 ;
   ***From the UNICON documentation for grdatn from March:


      A user from PPIC who has compared education distributions over
      time between the CPS and the Census, has concluded that people
      with grdhi=13 and grdcom=2 (did not complete grade) should be
      coded as "with some college" when trying to match grdatn codes
      with earlier years. ;

  ***The code for Oct is the original BLS coding in which all grades
     are one more than their corresponding values, e.g., no schooling
     equals 1, 1 year equals 2 etc. ;


  *First subtract 1 so that the years corespond to the values ;

   replace grdhi = grdhi - 1 ;
   tab grdhi ;


  *Now make this variable "highest grade completed" rather than
   attended by using the "grade completed" question ;

  gen ogrdhi = grdhi ;
  replace grdhi = ogrdhi - 1 if grdcom == 2 & ogrdhi ~= 13;

  sort _year ;

  list ogrdhi grdhi grdcom in 1/20 ;

  recode grdhi -1 = 0 ;

  gen edE = grdhi  ;
  lab var edE "ed attain, 1968-1991" ;


 *Also make a variable where I do not allow for special exceptions
 *for 13 years of schooling to test the sensitivity of my results
 *to this categorization ;

  gen grdhiv2 = ogrdhi ;
  replace grdhiv2 = ogrdhi - 1 if grdcom == 2  ;
  recode grdhiv2 -1 = 0 ;
  list ogrdhi grdhi grdhiv2 grdcom in 1/20 ;

  gen edEv2 = grdhiv2 ;



 tab _year if edE == . ;



 *Sex ;
 gen male = (sex == 1) ;



 *Define white (1), black (2), other (3), RACE variable
  Other includes those of mixed races in 2003 ;

  tab race ;

  gen race_c = race ;
  recode race_c 3/5 = 3 ;



 *Define hispanic variable ;

  tab spneth, miss ;



  *I'd want to replace the don't know's and no answers
  *with missings here if I were using this in the analysis.
  *But it's only included for exploratory purposes for now. ;


  gen hisp = (spneth >= 1 & spneth <= 7) ;

    *This var is only available from 1973 on. ;
     replace hisp = . if _year < 1973 ;



 *Define nativity var ;

  *Not available ;







 #delimit ;
 rename _year   y ;

 rename age     a ;

 rename edE    ed;
 rename edEv2    edv2;

 rename race_c  r ;
 rename hisp    hsp ;



 ********************************
 * Make husband/wife variables  *
 ******************************** ;

 gen hage = a if male == 1  ;
 gen wage = a if male == 0  ;

 gen hed = ed if male == 1  ;
 gen wed = ed if male == 0  ;

 gen hedv2 = edv2 if male == 1  ;
 gen wedv2 = edv2 if male == 0  ;

 gen hr = r if male == 1  ;
 gen wr = r if male == 0  ;

 gen hhsp = hsp if male == 1  ;
 gen whsp = hsp if male == 0  ;



 ***Use the final weight of the wife ;


 gen WEIGHT = wgtfnl/100 if male == 0 ;



 quietly compress ;

 gen hhcount = 1 ;

 *************************************************
 * CREATE COUPLE-LEVEL FILE                      *
 ************************************************* ;

 display _N ;

 gen oy = y ;

 replace y = oy - 1900 ;

 tab y ;

 *Make sure the data look right ;
 sort y hhid ;

 list y hhid hage wage hed wed male WEIGHT in 1/15 ;


 *First collapse: couple-level file ;
 collapse (mean) hage wage hed wed hr wr hhsp whsp hedv2 wedv2 WEIGHT (sum) hhcount, by(y mis state hhnum hhid subhh) ;

 *Make sure the data look right ;
 sort y hhid ;

 list y hhid hage wage hed wed WEIGHT in 1/15 , clean ;


 *drop those who dont have a spouse record, but first
  create a flag ;

 gen nospouse = (hage == . | wage == .);

 tab nospouse ;

 display _N ;

 drop if nospouse == 1 ;

 display _N ;

 *Drop those with more than 2 people in household.;

 gen drop10 = (hhcount > 2) ;

 tab drop10 ;


 drop if drop10 == 1 ;

 display _N ;

 gen drop11 = (hed == . | wed == .) ;

 tab drop11;
 tab y if drop11 == 1 ;



 drop if drop11 == 1 ;

 display _N ;





 tab hage , miss;
 tab wage , miss;
 tab hed  , miss;
 tab wed  , miss;



 gen hedc = hed ;
 gen wedc = wed ;

 recode hedc 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;
 recode wedc 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;

 gen hedcv2 = hedv2 ;
 gen wedcv2 = wedv2 ;

 recode hedcv2 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;
 recode wedcv2 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;



  gen hedc_o = hed ;
  gen wedc_o = wed ;


 recode hedc_o 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;
 recode wedc_o 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 ;



  gen hedc_g = hed ;
  gen wedc_g = wed ;

 recode hedc_g 0/11=1 12=2 13/15= 3 16 = 4 17/18 = 5 ;
 recode wedc_g 0/11=1 12=2 13/15= 3 16 = 4 17/18 = 5 ;


  gen hedc_d = hed ;
  gen wedc_d = wed ;

 recode hedc_d 0/9 = 1 10/11=2 12=3 13/15= 4 16 = 5 17/18 = 6 ;
 recode wedc_d 0/9 = 1 10/11=2 12=3 13/15= 4 16 = 5 17/18 = 6 ;


  lab def edc_g 1 "1:lt12"
                2 "2:12"
                3 "3:13-15"
                4 "4:16"
                5 "5:gt16" ;

  lab val hedc_g edc_g ;
  lab val wedc_g edc_g ;

  lab def edc_o 1 "1:lt10"
                2 "2:10-11"
                3 "3:12"
                4 "4:13-15"
                5 "5:ge16" ;

  lab val hedc_o edc_o ;
  lab val wedc_o edc_o ;


  lab def edc_d 1 "1:lt10"
                2 "2:10-11"
                3 "3:12"
                4 "4:13-15"
                5 "5:16"
                6 "6:gt16" ;

  lab val hedc_d edc_d ;
  lab val wedc_d edc_d ;


  ***Create the most detailed measure of education
     that is still relatively consistent across
     years.  Use Park (1996:426) 10 category
     scheme. ;

  gen hedc_dd = hed ;
  gen wedc_dd = wed ;

 recode hedc_dd 0=1 1/4=2 5/8=3 9=4 10=5 11=6 12=7 13/15=8 16=9 17/18=10 ;
 recode wedc_dd 0=1 1/4=2 5/8=3 9=4 10=5 11=6 12=7 13/15=8 16=9 17/18=10 ;

  lab def edc_dd 1 "1:lt1"
                 2 "2:1-4"
                 3 "3:5-8"
                 4 "4:9"
                 5 "5:10"
                 6 "6:11"
                 7 "7:12"
                 8 "8:13-15"
                 9 "9:16"
                10 "10:gt16" ;

  lab val hedc_dd edc_dd ;
  lab val wedc_dd edc_dd ;




  lab def r 1 "1:white" 2 "2:black" 3 "3:other" ;
  lab val hr r ;
  lab val wr r ;


  label var hedc "H's Ed: <10,10-11,12,13-15,16+" ;
  label var wedc "W's Ed: <10,10-11,12,13-15,16+" ;
  label var hedc_o "H's Ed: <10,10-11,12,13-15,16+" ;
  label var wedc_o "W's Ed: <10,10-11,12,13-15,16+" ;
  label var hedc_g "H's Ed: <12,13-15,16+" ;
  label var wedc_g "W's Ed: <12,13-15,16+" ;
  label var hedc_d "H's Ed: <12,13-15,16,>16" ;
  label var wedc_d "W's Ed: <12,13-15,16,>16" ;
  label var hedc_dd "H's Ed: 10 cat" ;
  label var wedc_dd "W's Ed: 10 cat" ;
  label var hr      "H's race, 3 cat" ;
  label var wr      "W's race, 3 cat" ;
  label var whsp    "H hispanic" ;
  label var hhsp    "W hispanic" ;




 describe ;




 quietly compress ;
 save "F:\Schwartz\cps_historical\data\couples_o6878.dta", replace ;

 log close ;

