#delimit ;
*couples_tab_rs.do ;
capture log close ;
log using "F:\Schwartz\rs_eam\filecreation\couples_tab_rs.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;


*********FILE PURPOSE***********

This file merges all of the individual files from different
places together to created a large contingency table. The
data come from 5 sources:

(1) Merged outgoing rotation file. 1979-2003.  Purchased
    from NBER.  Contains sample members who are in mis
    5 and 8.  NBER has basic monthly data available for
    download for 1976-78 online as well.  My guess is that
    they did not include these on the Merged Outgoing
    Rotation file because weekly hours/earnings are only
    included in the May extracts in these years.  Then it
    looks like it switched to all the months (see
    http://www.nber.org/cps-basic/ for documentation).

    I attempted to extend the Merged Outgoing Rotation
    file back to 1976 using the NBER data.  However,
    the hhids in 1976 and 1977 are not unique enough for me
    to confidently match husbands and wives. Instead, I'm
    using the UNICON data for these years.  According to
    the UNICON documentation, the Census made their own
    variables for making hhid more unique at least in 1976.
    There is no mention of this problem in 1977.


(2) March Supplement data. 1962, 1964-1978.  Data on CD
    from UNICON.


(3) June Supplement data.  1971, 1973-1977.  Data on CD
    from UNICON.


(4) October Supplement data. 1968-1978.  Data on CD from
    UNICON.


In addition, the program selects the appropriate
month-in-sample observations from the different CPS months
so that there is no overlap from month-to-month or
year-to-year.  Here is the algorithm I use for this:

  March 1962.        All mis.
  March 1964-1978.   5,6,7,8.
  October 1968-1978. 5,6,7,8.
  June 1971.         1,2,3 and 5,6,7.
  June 1973-1977.    5,6,7.
  1979-2003.         8.


There is no overlap between March and October, which is why
I can use month-in-sample 5,6,7, and 8 for these two months.
There is a 1/4 overlap between June and March.  The people
who are in their 5th interview month in March will be in
their last interview month in October so I use month-in-
samples 1,2,3 and 5,6,7 when there is no year-to-year
overlap (1971) and 5,6,7 when there is (1973-77).  When I
have all months I use the outgoing sample (month 8).





  ********************************
  * MERGED OUTGOING ROATION FILE *
  ******************************** ;



     use "F:\Schwartz\cps_historical\data\couples_morg.dta" ;


   ***Keep wives from 18 to 40 ;

   *** - crs 2/3/05 -- I'm changing this
         from 16 to 40 because from 1986-88
         16 & 17 year olds in the June CPS
         weren't asked about the date of their
         first marriages ;


      keep if wage >= 18 & wage <  41 ;


     ***Generate a variable to collapse the data by ;

       gen freq=1 ;

       rename intmonth m ;
       rename minsamp mis ;


  ***Keep if people in their last month of the survey ;


     keep if mis == 8 ;


     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort y m: egen double sumwgt = sum(WEIGHT) ;
        bysort y m: gen N = _N  ;


        bysort y m: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort y m: gen double WEIGHT = oweight*deflate ;



     ***Keep the variables I want ;

        keep wedc hedc hr wr hnv wnv y freq WEIGHT m ;



     ***Collapse ;

        collapse (sum) freq WEIGHT, by(wedc hedc hr wr hnv wnv y m) ;


         display _N ;


   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort wedc hedc hr wr hnv wnv y m

       tempfile full
       save `full'

       contract wedc hedc hr wr hnv wnv y m, freq(freqs) zero

       drop freqs
       sort wedc hedc hr wr hnv wnv y m

       merge wedc hedc hr wr hnv wnv y m using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort wedc hedc hr wr hnv wnv y m


    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;


      ***The nativity varialbes are only available from 1994 on.
         Drop the 0s and 1s before 1994 and the missings after. ;


         display _N ;

         drop if (hnv ~= . | wnv ~= .) & y <  94 ;
         drop if (hnv == . | wnv == .) & y >= 94 ;

         display _N ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;



         *Generate variable that differentiates census from cps ;

          gen cps = 1 ;



     ***Save a temporary file ;

        tempfile temp1 ;
        save `temp1' ;






     **************************
     * APPEND MARCH 1962-1978 *
     ************************** ;


     use "F:\Schwartz\cps_historical\data\couples_m6278.dta" ;


   ***Keep wives from 18 to 40 ;


      keep if wage >= 18 & wage <  41 ;



   ***KEEP THE RIGHT MIS (see algorithm above) ;


      tab y mis ;

      keep if (mis >= 1 & mis <= 8 & y == 62) | (mis >= 5 & mis <= 8 & y > 62 & y <= 78) ;

      tab y mis ;


     ***Generate a variable to collapse the data by ;

       gen freq=1 ;



     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort y: egen double sumwgt = sum(WEIGHT) ;
        bysort y: gen N = _N  ;


        bysort y: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort y: gen double WEIGHT = oweight*deflate ;



     ***Keep the variables I want ;

        keep wedc hedc hr wr y freq WEIGHT ;



     ***Collapse ;

        collapse (sum) freq WEIGHT, by(wedc hedc hr wr y) ;

         display _N ;






   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort wedc hedc hr wr y

       tempfile full
       save `full'

       contract wedc hedc hr wr y , freq(freqs) zero

       drop freqs
       sort wedc hedc hr wr y

       merge wedc hedc hr wr y using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort wedc hedc hr wr y


    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;



         *Generate variable that differentiates census from cps ;

          gen cps = 1 ;


         *Month variable.  This is March ;

          gen m = 3 ;


         append using `temp1' ;







        tab y [w=freq] ;



         tempfile temp2 ;
         save `temp2' ;


     ****************************
     * APPEND OCTOBER 1968-1978 *
     **************************** ;


     use "F:\Schwartz\cps_historical\data\couples_o6878.dta" ;


   ***Keep wives from 18 to 40 ;


      keep if wage >= 18 & wage <  41 ;


   ***KEEP THE RIGHT MIS ;

      tab y mis ;

      keep if mis >= 5 & mis <= 8 ;

      tab y mis ;



     ***Generate a variable to collapse the data by ;

       gen freq=1 ;



     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort y: egen double sumwgt = sum(WEIGHT) ;
        bysort y: gen N = _N  ;


        bysort y: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort y: gen double WEIGHT = oweight*deflate ;



     ***Keep the variables I want ;

        keep wedc hedc hr wr y freq WEIGHT ;



     ***Collapse ;

        collapse (sum) freq WEIGHT, by(wedc hedc hr wr y) ;

         display _N ;




   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort wedc hedc hr wr  y

       tempfile full
       save `full'

       contract wedc hedc hr wr y , freq(freqs) zero

       drop freqs
       sort wedc hedc hr wr y

       merge wedc hedc hr wr y using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort wedc hedc hr wr y


    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;


         *Generate variable that differentiates census from cps ;

          gen cps = 1 ;


         *This is October ;

          gen m = 10 ;



         append using `temp2' ;


        tab y [w=freq] ;




         tempfile temp3 ;
         save `temp3' ;



     ****************************
     * APPEND JUNE    1971-1978 *
     **************************** ;


     use "F:\Schwartz\cps_historical\data\couples_j7178.dta" ;


   ***Keep wives from 18 to 40 ;


      keep if wage >= 18 & wage <  41 ;


   ***KEEP THE RIGHT MIS ;


      tab y mis ;

      keep if (((mis >= 1 & mis <= 3) | (mis >= 5 & mis <= 7)) & y == 71) |(mis >= 5 & mis <= 7 & y > 71) ;


      tab y mis ;


     ***Generate a variable to collapse the data by ;

       gen freq=1 ;



     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort y: egen double sumwgt = sum(WEIGHT) ;
        bysort y: gen N = _N  ;


        bysort y: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort y: gen double WEIGHT = oweight*deflate ;



     ***Keep the variables I want ;

        keep wedc hedc hr wr y freq WEIGHT ;



     ***Collapse ;

        collapse (sum) freq WEIGHT, by(wedc hedc hr wr y) ;

         display _N ;




   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort wedc hedc hr wr y

       tempfile full
       save `full'

       contract wedc hedc hr wr y , freq(freqs) zero

       drop freqs
       sort wedc hedc hr wr y

       merge wedc hedc hr wr y using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort wedc hedc hr wr y


    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;



         *Generate variable that differentiates census from cps ;

          gen cps = 1 ;


         *This is June ;

          gen m = 6 ;



         append using `temp3' ;



        tab y [w=freq] ;



         tempfile temp4 ;
         save `temp4' ;




     **************************
     * APPEND CENSUS          *
     ************************** ;


     use "F:\Schwartz\rs_eam\data\census_spouse_wrace.dta" ;


   keep if wage >= 18 & wage <  41 ;


   ***Some bookkeeping stuff ;

      rename year y ;

      tab y ;

      gen y2 = y - 1900 ;

      tab y2 ;
      drop y ;
      rename y2 y ;


   gen freq=1 ;



     ***CPS month can't be a string for my collapse command ;

       gen cps = 0 ;



       lab def cps 1 "CPS" 0 "CENSUS" ;
       lab val cps cps ;





     ***Generate a variable to collapse the data by ;





     ***This part deflates the weights so that the original
        sample size is maintained ;


        replace WEIGHT = WEIGHT/100 ;
        bysort y: egen sumwgt = sum(WEIGHT) ;
        bysort y: gen N = _N  ;


        bysort y: gen deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort cps y: gen WEIGHT = oweight*deflate ;


     ***Keep the variables I want ;

        keep wedc hedc hr wr hnv wnv y freq WEIGHT cps ;



     ***Collapse ;

        collapse  (sum) freq WEIGHT, by(cps y wedc hedc hr wr hnv wnv) ;



         ***Make sure it works ;

            tab y [w=freq] ;


   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort cps wedc hedc hr wr hnv wnv y

       tempfile full
       save `full'

       contract cps wedc hedc hr wr hnv wnv y, freq(freqs) zero

       drop freqs
       sort cps wedc hedc hr wr hnv wnv y

       merge cps wedc hedc hr wr hnv wnv y using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort cps wedc hedc hr wr hnv wnv y



    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;



         *Month variable.  Call if 13 for census ;

          gen m = 13 ;

     ***Append CPS file ;

       append using `temp4' ;




***Look at the contents ;

   lab val cps cps ;

   tab y cps [w=freq] ;
   tab y m [w=freq] ;



**Collapse across months ;


     ***Collapse ;

        collapse  (sum) freq WEIGHT, by(cps y wedc hedc hr wr hnv wnv) ;

   tab y cps [w=freq] ;
   tab y ;

   *Ok, the data set has the right number of cells now ;



         save "F:\Schwartz\rs_eam\data\couples_tab_rs.dta",replace ;

         log close ;



