#delimit ;
*jun_newly_rs.do ;
capture log close ;
log using "F:\Schwartz\rs_eam\filecreation\june_newly_rs.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 700m ;


****************************************************
*                                                  *
*                                                  *
*                                                  *
**************************************************** ;




***Here is the June 1971-1998 (1995) data ;


    use "F:\Schwartz\cps_historical\raw\jdat_7198\jun71.dta", clear ;

    foreach num of numlist  73/77 79 80/88 90/92 94 95 { ;

      quietly append using "F:\Schwartz\cps_historical\raw\jdat_7198\jun`num'.dta" ;

    } ;




   *Keep if adult record ;
     drop if (intstat ~= 1 | age < 15) & _year >= 1994 ;
     drop if (rectyp ~= 1 ) & _year < 1994 ;



     #delimit cr


     *For the June 1975, I have to create my own household id

     gen str1 subhh_s = string(subhh)   if _year== 1975
     gen str2 sernum_s= string(sernum)  if _year== 1975
     gen str4 segnum_s = string(segnum) if _year== 1975
     gen str5 random_s = string(random) if _year== 1975
     replace hhid = (random_s + segnum_s + sernum_s + subhh_s) if _year == 1975


     drop random* segnum* sernum* subhh*





***The first part of the file is the same as the files
***for prevailing marriages


    ****Define married couples***



   *Identify married people (spouse present)



        gen m = (marstat == 1 | marstat == 2)  /*1= civilian spouse present
                                                 2= AF spouse present*/


        tab marstat m

        tab _year m if age >= 18 & age <= 64, row
        keep if m == 1



   *Keep married couples


       gen mc = 0
       replace mc = 1 if (rrp == 1 | rrp == 3           ) & _year >= 1971 & _year <= 1988
       replace mc = 1 if (rrp == 1 | rrp == 3 | rrp == 4) & _year >  1988 & _year <= 1993
       replace mc = 1 if (rrp == 1 | rrp == 3           ) & _year >  1993 & _year <= 2000

       tab rrp mc if _year >= 1971 & _year <= 1988
       tab rrp mc if _year >  1988 & _year <= 1993
       tab rrp mc if _year >  1993 & _year <= 2000

       tab mc
       keep if mc == 1

       drop mc




   *Drop if there is more than one married couple in the household


       bysort _year mis state hhnum hhid famnum: egen summ = sum(m)


       tab summ
       gen xsum = (summ ~= 2)
       tab _year xsum

       drop xsum

       drop if summ ~= 2


   *Drop if they appear to be same sex.


       bysort _year mis state hhnum hhid famnum: egen sumsex = sum(sex)
       tab sumsex

       keep if sumsex == 3



#delimit ;

*First marriage date

  In 1995, MAR1M is only asked of people who have been
  married 2 or more times.  A different question,
  MARLM (month of latest marriage) is asked of all
  women who have ever been married.  Therefore, I need
  to use this question in combination with the number
  of times married variable MARNUM to get newlyweds in
  their first marriages.


  crs 10/4/04

  ;




  replace marly = marly + 1900 ;
  replace mar1y = mar1y + 1900 ;



  **Create a "years since first marriage" variable ;

    **(1) Interview date ;
          gen intdate = ym(_year, 6) ;
          format intdate %tm ;

    **(2) First marriage data ;
          gen fmdate = . ;

          replace fmdate = ym(marly, marlm) if marnum == 1 & _year == 1995 ;
          replace fmdate = . if (marlm < 1 | marlm > 12 | marly == .) & marnum == 1 & _year == 1995 ;

          replace fmdate = ym(mar1y, mar1m) if               _year ~= 1995 ;
          replace fmdate = . if  (mar1m < 1 | mar1m > 12 | mar1y == .) & _year ~= 1995 ;

          format fmdate %tm ;

          list fmdate in 1/30 ;


    **(3) Gen months since first marriage ;

          gen dur_mths = intdate - fmdate ;

          summarize dur_mths, detail ;


          *Negative durations ;
          list fmdate intdate dur_mths if dur_mths < 0 ;

          *Recode these people as missings ;
          replace dur_mths = . if dur_mths < 0 ;



          list fmdate intdate dur_mths in 1/50 ;


  **Figure out how old women were when they first got married.
    First, use AGE and BRMO to calculate age in months at the
    interview. Compare to the constructed UNICON variable AGEMO
    (I am not using this variable directly because some of the
    values look strange). Then use my AGEMO variable and FMDATE
    to determine a more precise age at first marriage.

    Note: I'm not using the UNICON birth year variable (BRYR)
    because it's not available for some years.

    Here's the Universe for this variable:

    Note:
        1971            Universe - adult females
        1973-1974       Universe - those women 14-59 and has ever been married
                                   (femstat=1)
        1975            Universe - all adults
        1976            Universe - those women ever married ages 14-59 or never
                                   married ages 18-59 (1<=femstat<=2)
        1977-1979       Universe - all females
                        In 1979, tabs indicate 43 values out of range.
        1980            Universe - all adults
        1981-1983       Universe - all females
        1984            Universe - women who have had children (1<=numbaby<=10)
        1985-1988       Universe - all adults
        1990            Universe - women 15-65 (1<=femstat<=2)
        1992            Universe - women 15-44 (sex=2 & 15<=age<=44)
        1995            Universe - women 15-65 (sex=2 & 15<=age<=65))

    ;


    *Preserve unicon birth year variable ;
    gen Ubryr = bryr ;
    drop bryr ;

    *My own birth year variable;
    gen     bryr = (_year - age) if brmo    <= 6 ;
    replace bryr = (_year - age - 1) if brmo > 6 ;

    *Birth month and year ;
    gen bym = ym(bryr, brmo) ;
    format bym %tm ;

    *Preserve unicon age in months variable ;
    gen Uagemo = agemo ;
    drop agemo ;

    *My own age in months variable (at interview) ;
    gen agemo = intdate - bym ;

    *Divide by 12 ;
    gen age_m = agemo/12 ;

    *Age at first marriage in months ;
    gen age_fm = (agemo - dur_mths)/12 ;

    *Where the more detailed information is not available use
     whole years ;

    replace age_fm = (age - (dur_mths/12)) if age_fm == . ;



    *Check ;

      preserve ;
      sample 50, count ;

       list sex Ubryr Uagemo _year age bryr brmo bym agemo age_m ;
       list sex intdate agemo age_m fmdate age_fm mar1m mar1y ;

     restore ;





 *Educational attainment.

  NOTE: The variables which indicate educational attainment
        switched in 1992. Pre-1992 there are two varaibles
        that need to be used to construct a highest grade
        of school completed variable: grdhi (hiest grade
        attended) and grdcom (highest grade completed). In
        1992 and after, there is a single variable, grdatn,
        which indicates highest grade completed. Therefore,
        I have to do the coding in two steps. (However,
        1992 has both sets of variables)       -crs 9/6/01 ;


  *First subtract 1 so that the years corespond to the values ;


   tab grdhi if _year <= 1988 ;
   tab grdhi if _year >  1988 ;

   replace grdhi = grdhi - 1 if _year <= 1988 ;


   tab grdhi if _year <= 1988 ;
   tab grdhi if _year >  1988 ;


   gen ogrdhi = grdhi ;


   replace grdhi = grdhi - 1 if grdcom == 2 & grdhi ~= 13;


   sort _year ;

   list ogrdhi grdhi grdcom in 1/50 ;


   recode grdhi -1 = 0 ;


   gen edE = grdhi if _year >= 1962 & _year <= 1991 ;

   lab var edE "ed attain, through 1991" ;




  *1992-2003 ;
   gen edL = grdatn if _year >= 1992 & _year <= 2003 ;

   lab var edL "ed attain, 1992-2003" ;


  *
     Code:

                Less than 1st grade                                         31
                1st, 2nd, 3rd or 4th grade                                  32
                5th or 6th grade                                            33
                7th or 8th grade                                            34
                9th grade                                                   35
                10th grade                                                  36
                11th grade                                                  37
                12th grade or no diploma                                    38
                High school graduate - High school diploma or equivalent    39
                Some college but no degree                                  40
                Associate's degree in college - occupational/vocational     41
                Associate's degree in college - academic                    42
                Bachelor's degree (e.g., BA, BS, AB)                        43
                Master's degree (e.g., MA, MS, MEng, MEd, MSW, MBA)         44
                Professional school degree (e.g.: MD, DDS, DVM, LLB, JD)    45
                Doctorate degree (e.g., PhD, EdD)                           46




  ;
   gen     educ = edE     if                                   _year >=1962 & _year <=1991 ;

   replace educ = 0  if edL == 00 | edL == 31                & _year >=1992 & _year <=2003 ;

   replace educ = 4  if edL == 32                            & _year >=1992 & _year <=2003 ;

   replace educ = 6  if edL == 33                            & _year >=1992 & _year <=2003 ;

   replace educ = 8  if edL == 34                            & _year >=1992 & _year <=2003 ;

   replace educ = 9  if edL == 35                            & _year >=1992 & _year <=2003 ;

   replace educ = 10 if edL == 36                            & _year >=1992 & _year <=2003 ;

   replace educ = 11 if edL == 37                            & _year >=1992 & _year <=2003 ;

   replace educ = 12 if edL == 38 | edL == 39                & _year >=1992 & _year <=2003 ;

   replace educ = 13 if edL == 40 | edL == 41 | edL == 42    & _year >=1992 & _year <=2003 ;

  /*14*/
   replace educ = 16 if edL == 43                            & _year >=1992 & _year <=2003 ;

   replace educ = 18 if edL >= 44 & edL <= 46                & _year >=1992 & _year <=2003 ;


   tab grdhi educ ;
   tab grdatn educ ;




 *Sex ;
 gen male = (sex == 1) ;


 *Define white (1), black (2), other (3), RACE variable
  Other includes those of mixed races in 2003 ;

  tab race ;

  gen race_c = race ;
  recode race_c 3/5 = 3 ;

  tab race race_c ;



 *Define hispanic variable ;

  tab spneth, miss ;
  replace spneth = "10" if spneth == "A" ;
  destring spneth, replace ;

  gen hisp = 0 ;
  replace hisp = 1 if (spneth >= 1 & spneth <= 7) ;

  tab spneth hisp ;


 *Define nativity var ;
  gen native = 0 ;

  *Born in U.S. Puerto Rico, or outlying area of US ;
   replace native = 1 if natvty >= 1 & natvty <= 3 & (_year == 1986 | _year == 1988 | _year == 1991) ;

   *Blank, but not foreign born ;
    replace native = 1 if (natvty == 99 & _year == 1988) | (natvty == 30 & _year == 1991) ;

   *No response ;
    replace native = . if (natvty == 99 & (_year == 1986 | _year == 1991)) ;

  *Born in U.S., Puerto Rico, or outlying area of U.S. ;
   replace native = 1 if (natvty == 57 | natvty == 60 | natvty == 66 | natvty == 72 | natvty == 78) & (_year >= 1994);


  *Years in which this info was not collected ;
   replace native = . if (_year < 1986 | _year == 1987 | _year == 1989 | _year == 1990) ;


  tab natvty native if (_year == 1986 | _year == 1988 | _year == 1991) ;
  tab natvty native if (_year >= 1994) ;




 #delimit ;
 rename _year   y ;

 rename age     a ;

 rename educ    ed;

 rename dur_mths dur ;



*******************************
* Make husband/wife variables *
******************************* ;

gen hage = a if male == 1 & m == 1 ;
gen wage = a if male == 0 & m == 1 ;

gen hed = ed if male == 1 & m == 1 ;
gen wed = ed if male == 0 & m == 1 ;


gen hdur = dur if male == 1 & m == 1 ;
gen wdur = dur if male == 0 & m == 1 ;

gen wagemarr = age_fm if male == 0 & m == 1 ;
gen hagemarr = age_fm if male == 1 & m == 1 ;

gen hmarnum = marnum if male == 1 & m == 1 ;
gen wmarnum = marnum if male == 0 & m == 1 ;


***Use the wife's final weight. ;

 gen     WEIGHT = wgtfnl/100 if male == 0 ;


quietly compress ;

gen hhcount = 1 ;

*************************************************
* CREATE COUPLE-LEVEL FILE                      *
************************************************* ;



 display _N ;

 gen oy = y ;

 replace y = oy - 1900 ;

 tab y ;

 *Make sure the data look right ;
 sort y mis state hhnum hhid famnum ;


 list y hhid hage wage hed wed hdur wdur male WEIGHT in 1/30 ;

 list y hhid hdur wdur wagemarr hagemarr mar1m mar1y male WEIGHT in 1/30 ;


 *First collapse: couple-level file ;
 collapse (mean) hage wage hed wed hdur wdur WEIGHT wagemarr hmarnum wmarnum (sum) hhcount, by(y mis state hhnum hhid famnum) ;

 *Make sure the data look right ;
 sort y mis state hhnum hhid famnum ;

 list hhid hage wage hed wed hdur wdur WEIGHT in 1/30 , clean ;

 *How often do husbands and wives disagree about
 *if they are newlyweds? ;

  *Say they disagree if they're off by more than 6 months ;
  gen months_off = abs(hdur-wdur) ;
  gen wh_dis = (months_off > 6) ;
   replace wh_dis = . if hdur == . | wdur == . ;

  tab wh_dis ;
  tab wmarnum wh_dis, row ;
  tab hmarnum wh_dis, row ;
  tab wh_dis if (wmarnum == hmarnum & wmarnum == 1) ;

  summarize months_off if wmarnum == hmarnum & wmarnum == 1 & wh_dis == 1, detail ;

  drop wh_dis ;

 *ANSWER: sometimes ;


 *****Define newlyweds according to the wife's
 *****report. ;


 gen dur = wdur ;

  drop wdur hdur ;




 *drop those who dont have a spouse record, but first
  create a flag ;

 gen nospouse = (hage == . | wage == .) ;

 tab nospouse ;

 display _N ;

 drop if nospouse == 1 ;



 display _N ;

 *Drop those with more than 2 people in household. We don't
  know which people form the marital unit ;

 gen drop10 = (hhcount > 2) ;

 tab drop10 ;


 drop if drop10 == 1 ;

 display _N ;

 gen drop11 = (hed == . | wed == .) ;

 tab drop11;
 tab y if drop11 == 1 ;



 drop if drop11 == 1 ;

 display _N ;





 tab hage , miss;
 tab wage , miss;
 tab hed  , miss;
 tab wed  , miss;



 gen hedc = hed ;

 gen wedc = wed ;

 recode hedc 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 -9/-1 = .;

 recode wedc 0/9=1 10/11=2 12=3 13/15= 4 16/18 = 5 -9/-1 = .;

 drop if wedc == . | hedc == . ;

 describe ;




 quietly compress ;
 save "F:\Schwartz\rs_eam\data\june_newly_rs.dta", replace ;

 log close ;




