#delimit ;
*newly_tab.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\filecreation\newlyweds\newly_tab.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;


*********FILE PURPOSE***********

Add Census data to June CPS data for
newlyweds. Create data table.

********************************





     **************************
     * JUNE 1971-1995         *
     ************************** ;


     use "F:\Schwartz\rs_eam\data\june_newly_rs.dta" ;


   ***Keep wives married 2 years or less before interview ;

      keep if dur <= 24 ;

      tab y ;
      summarize dur ;


   ***For years in which people were interviewed in the year before
      & who were married in the June before I need to avoid counting
      new marriages twice.

      Those at risk of being counted twice are those who were married
      12 months or more before the current interview AND who were in
      the incoming rotation group (mis 1-4) in the previous year but
      are now in the outgonig rotation groups mis (5-8).

      Drop people in the current year if they were:
      (1) married in a year in which there was a June supplement
          in the previous year (1974 1975 1976 1977 1980 1981 1982
          1983 1986 1987 1988).
      (2) were married between 12 and 24 months prior to the interview
          AND
      (3) MIS 5-8. ;



       gen flag = (dur >= 12 & (mis >= 5 & mis <= 8) & (
                                                        (y >= 74 & y <= 77) |
                                                        (y >= 80 & y <= 83) |
                                                        (y >= 86 & y <= 88)
                                                                            )) ;

       tab y flag ;
       tab dur if flag == 1 ;
       tab mis if flag == 1 ;

       drop if flag == 1 ;

       tab y ;


   ***Keep wives from 18 to 40 ;


      keep if wage >= 18 & wage <  41 ;

      tab y ;
      summarize wage ;


     ***Generate a variable to collapse the data by ;

       gen freq=1 ;



     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort y: egen double sumwgt = sum(WEIGHT) ;
        bysort y: gen N = _N  ;


        bysort y: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort y: gen double WEIGHT = oweight*deflate ;



     ***Keep the variables I want ;

        keep wedc hedc y freq WEIGHT ;



     ***Collapse ;

        collapse (sum) freq WEIGHT, by(wedc hedc y) ;

         display _N ;






   #delimit cr


   ****ADD ZERO CELLS TO THE TABLE***


       sort wedc hedc y

       tempfile full
       save `full'

       contract wedc hedc y , freq(freqs) zero

       drop freqs
       sort wedc hedc y

       merge wedc hedc y using `full'
       replace freq = 0 if freq == .
       replace WEIGHT = 0 if freq == 0

       display _N
       drop _merge

       sort wedc hedc y


    #delimit ;


         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;



         *Generate variable that differentiates census from cps ;

          gen cps = 1 ;


         tempfile temp1 ;
         save `temp1' ;





     **************************
     * APPEND CENSUS          *
     ************************** ;


     use "F:\Schwartz\rs_eam\data\census_spouse_wrace.dta" ;


   ***For 1940 there is only age at marriage.  Following Mare (1991)
      define newlyweds as those "who married when their age was the
      same or one year less than their age at the census date" (pp. 18).

      For 1960, 70, and 80 I have quarter of marriage.  Include those
      married between 0 and 12 months prior to the survey. Here DUR is
      measured in years ;


      keep if (wage - wagemarr >= 0 & wage - wagemarr <= 1 & y == 1940) |
              (dur <= 1  & y >= 1960 & y <= 2000) ;


      tab y ;
      bysort y: tab dur ;


   **Keep wives 18 through 40 ;

      keep if wage >= 18 & wage < 41 ;

      tab y ;
      tab wage ;


   ***Some bookkeeping stuff ;

      rename year y ;

      tab y ;

      gen y2 = y - 1900 ;

      tab y2 ;
      drop y ;
      rename y2 y ;


   gen freq=1 ;



     ***CPS month can't be a string for my collapse command ;

       gen cps = 0 ;



       lab def cps 1 "CPS" 0 "CENSUS" ;
       lab val cps cps ;





     ***Generate a variable to collapse the data by ;





     ***This part deflates the weights so that the original
        sample size is maintained ;


        replace WEIGHT = WEIGHT/100 ;
        bysort cps y: egen sumwgt = sum(WEIGHT) ;
        bysort cps y: gen N = _N  ;


        bysort cps y: gen deflate = N/sumwgt ;



        *preserve original weight variables ;
         rename WEIGHT oweight ;

        bysort cps y: gen WEIGHT = oweight*deflate ;


     ***Keep the variables I want ;

        keep wedc hedc y freq WEIGHT cps ;



     ***Collapse ;

        collapse  (sum) freq WEIGHT, by(cps y wedc hedc ) ;



         ***Make sure it works ;

            tab y [w=freq] ;



         ***The sum of WEIGHT should equal the sum of freq ;

            egen sW = sum(WEIGHT) ;
            egen sF = sum(freq) ;

            display "sum of the weights: " sW ;
            display "sum of the freqs:   " sF ;

            drop sW sF ;


     ***Append CPS file ;

       append using `temp1' ;




***Look at the contents ;

   lab val cps cps ;

   tab y cps [w=freq] ;



         save "F:\Schwartz\cps_historical\data\newly_tab.dta",replace ;

         log close ;



